tsvd

Function tsvd 

pub fn tsvd(
    local_field: &[f64],
    mask: &[u8],
    nx: usize,
    ny: usize,
    nz: usize,
    vsx: f64,
    vsy: f64,
    vsz: f64,
    bdir: (f64, f64, f64),
    threshold: f64,
) -> Vec<f64>
Truncated singular value decomposition (TSVD) variant

Similar to TKD but zeros out values below threshold instead of truncating. This produces smoother results but may have more artifacts at the magic angle.